       
*CURRENT*
---
    
- 2018-03-07 (Laisky) feat: add `/email-proxy/` -> [view commit](https://github.com/Laisky/ramjet/commit/71d7f6c1c4be92185eb02721262136d67cdc328e)
- 2017-11-07 (Laisky) fix: remove some movoto settins -> [view commit](https://github.com/Laisky/ramjet/commit/27262df48e271bdcd1dc5f7c50b38a65ba3bc6aa)
- 2017-11-07 (Laisky) ci: changelog -> [view commit](https://github.com/Laisky/ramjet/commit/af4536129bae8c28e61354a3d5d8bb69c4fd5789)
- 2017-11-07 (Laisky) fix: some bugs -> [view commit](https://github.com/Laisky/ramjet/commit/e8787a80674feffae1ec0b5dd00758dd1344e099)
- 2017-11-07 (Laisky) fix: a log of changings -> [view commit](https://github.com/Laisky/ramjet/commit/c08ced7b9cf82cd8ea28216ec6297459651bf4ad)
- 2017-09-19 (Laisky) 1.7.1 -> [view commit](https://github.com/Laisky/ramjet/commit/979517cd078d620cabe9945b0869f9d524c7bee7)
- 2017-09-19 (Laisky) fix: twitter logger error -> [view commit](https://github.com/Laisky/ramjet/commit/c1f389e0f167583f1ad37ff254d29de4e1bbfe98)
- 2017-09-19 (Laisky) fix: not subtract a tz aware dt -> [view commit](https://github.com/Laisky/ramjet/commit/8dd9b8aec55522b9d3cce58c83efb74c2af91b44)
- 2017-09-19 (Laisky) fix: monitors.ssl_cert error -> [view commit](https://github.com/Laisky/ramjet/commit/b9b109be2dc365ad44bebd37b54bf569c7e57a46)
- 2017-09-19 (Laisky) chore: fix supervisor conf -> [view commit](https://github.com/Laisky/ramjet/commit/f61f454d4bc173c3d15bddde0a0df04983c6ca84)
- 2017-09-19 (Laisky) 1.7 -> [view commit](https://github.com/Laisky/ramjet/commit/390354d5a67c59e5fea6ca25df8a66377dfbd27c)
- 2017-09-19 (Laisky) feat: add ssl_cert monitors -> [view commit](https://github.com/Laisky/ramjet/commit/709350e5b37fad9eb67fa7d2d60accb28f2b4017)
- 2017-05-27 (Laisky) fix: 前端架子搭起来 -> [view commit](https://github.com/Laisky/ramjet/commit/7581fbd747fb787c2df67fb51aeca7c8128a3a0d)
- 2017-05-27 (Laisky) fix: some typos and static versions -> [view commit](https://github.com/Laisky/ramjet/commit/ac1c8d36f67f8e6430ddf6b76bd023d5eca40571)
- 2017-05-26 (Laisky) feat: add support to FE (react & redux & router) -> [view commit](https://github.com/Laisky/ramjet/commit/07f979fca9798a96cbde849662e007f912ea0eef)
- 2017-05-11 (Laisky) fix: add more stopwords to keyword -> [view commit](https://github.com/Laisky/ramjet/commit/a5c5c19007cf0b33b78a4c4cd9e7a785ea46e55a)
- 2017-04-03 (Laisky) fix: keyword miss some posts -> [view commit](https://github.com/Laisky/ramjet/commit/d13db555ad69e3dc1f01378e9f77e21ae3bea697)
- 2017-04-03 (Laisky) feat: loads keywords for each post -> [view commit](https://github.com/Laisky/ramjet/commit/aff9e9797e468e878f53af771b4277a727fb0411)
- 2017-02-27 (Laisky) feat: add jinja2 templates -> [view commit](https://github.com/Laisky/ramjet/commit/39b5424a40fc79525fb003a86edafbfc349c24cf)
- 2017-02-26 (Laisky) perf: nonblock to request aws api -> [view commit](https://github.com/Laisky/ramjet/commit/a0fc05c00b3c618a18967d46cd04b87554fcb9f5)
- 2017-02-24 (Laisky) 1.6 -> [view commit](https://github.com/Laisky/ramjet/commit/ccd9af693c33e2838c55b5ed459a565abf56eab6)
- 2017-02-24 (Laisky) feat: aws rekognition -> [view commit](https://github.com/Laisky/ramjet/commit/fefe17c6217fd358c09e9bf38ab276b1e21c5121)    
       
*1.5*
---
    
- 2017-01-22 (Laisky) 1.5 -> [view commit](https://github.com/Laisky/ramjet/commit/b7603d03121d625589bc79e4b96747eddb76f919)
- 2017-01-22 (Laisky) fix: url prefix -> [view commit](https://github.com/Laisky/ramjet/commit/4e94d7c08d3646dae7ca88320e960e0f11c67569)
- 2016-10-22 (Laisky) feat: 增加登陆到 blog 的功能 -> [view commit](https://github.com/Laisky/ramjet/commit/48eeb1e26ae6564f93d26189e8bc809d228d4c09)
- 2016-10-20 (Laisky) feat: 增加 -t 和 -e 命令行接口 -> [view commit](https://github.com/Laisky/ramjet/commit/1b3e3607f07f90962005b6e9cf514532d9081dbf)
- 2016-10-19 (Laisky) refactor: 重写命令行命令解析 -> [view commit](https://github.com/Laisky/ramjet/commit/4a0fcf3fbd7eb478e452d1857dd718501e524c3e)
- 2016-10-18 (Laisky) docs: update readme -> [view commit](https://github.com/Laisky/ramjet/commit/29db3dcf566d6485b9e00cfa61267c1e2959a5e0)
- 2016-10-15 (Laisky) fix: 打开 keyword -> [view commit](https://github.com/Laisky/ramjet/commit/98f3134d7367b0d6d1eebc35e8805134c563966b)
- 2016-10-14 (Laisky) feat: 抓去所有人的推文 -> [view commit](https://github.com/Laisky/ramjet/commit/76b0a7f0bf46b627c5de5358d6a1aa3858f06f48)
- 2016-10-14 (Laisky) feat: 增加 Twitter Oauth 登陆 -> [view commit](https://github.com/Laisky/ramjet/commit/fd340aca5ff77aab013ca6aa2b9f9df1a3ca97f7)
- 2016-10-13 (Laisky) chore: 增加 Nginx 和 supervisor 配置 -> [view commit](https://github.com/Laisky/ramjet/commit/4669895490613bc4c8ec5e28f4c2804262373102)    
       
*1.4*
---
    
- 2016-10-11 (Laisky) 1.4 -> [view commit](https://github.com/Laisky/ramjet/commit/db36d85f548260177ea9df06ddbf71f1c83b4184)
- 2016-10-11 (Laisky) fix: 数据库连接方式 -> [view commit](https://github.com/Laisky/ramjet/commit/7f1634d760a9c2e1b8bb1e0737defe77c8a8913e)
- 2016-10-11 (Laisky) fix: typo -> [view commit](https://github.com/Laisky/ramjet/commit/a2de59f3933b0e4c9383535ae6009fa4886b9017)
- 2016-10-11 (Laisky) feat: 定时爬取推文 -> [view commit](https://github.com/Laisky/ramjet/commit/06d5f88a1bb5e5d6537ce52ac3db234b72d1e8f3)
- 2016-08-29 (Laisky) feat: 增加 keyword 统计 -> [view commit](https://github.com/Laisky/ramjet/commit/011af289eaf69f0606317807d579b0597c3bfccf)    
       
*1.3*
---
    
- 2016-10-10 (Laisky) 1.3 -> [view commit](https://github.com/Laisky/ramjet/commit/6a7d7952209c51ab429cb79825d05aea9ca6d51a)
- 2016-10-10 (Laisky) feat: 增加 http handler -> [view commit](https://github.com/Laisky/ramjet/commit/0417a079a5740284494c9acc91fd023e600c30ba)
- 2016-08-02 (Laisky) docs: README 中的错误示例 -> [view commit](https://github.com/Laisky/ramjet/commit/33fffccd333b2ba7a31fc88b555b7b94bd97a13e)    
       
*1.2.2*
---
    
- 2016-08-02 (Laisky) 1.2.2 -> [view commit](https://github.com/Laisky/ramjet/commit/77858d56e675d766d7daebc4f475dbb3030107d4)
- 2016-08-02 (Laisky) docs: pypi long description -> [view commit](https://github.com/Laisky/ramjet/commit/8da79573defb1c49f9da607854b1cf54be56ab6c)    
       
*1.2.1*
---
    
- 2016-08-02 (Laisky) 1.2.1 -> [view commit](https://github.com/Laisky/ramjet/commit/ac318b3721cadc0abde1e1c1e7b4fcbeed1b63f3)
- 2016-08-02 (Laisky) docs: 还原 README -> [view commit](https://github.com/Laisky/ramjet/commit/c1b5ba8f5f306194ae5518b88aab330dae630c8d)
- 2016-08-01 (Laisky) docs: README 里的 CHANGELOG 指向错误 -> [view commit](https://github.com/Laisky/ramjet/commit/e3dc74aa46abf5f68527dd9a6c08b5d3b7b2808e)    
       
*1.2*
---
    
- 2016-08-01 (Laisky) 1.2 -> [view commit](https://github.com/Laisky/ramjet/commit/563f65ea65aac9fd0ca2fdf8394ce428fda922e0)
- 2016-08-01 (Laisky) refactor: 用 asyncio 重构 -> [view commit](https://github.com/Laisky/ramjet/commit/8ada8c313470fdb65647394e0caf42e822ee8633)
- 2016-01-08 (Laisky) docs: use commitizen -> [view commit](https://github.com/Laisky/ramjet/commit/800a8ffab6e9b3a19ead1dc4892c1fcfa042d316)
- 2016-01-08 (Laisky) docs: add commitizen -> [view commit](https://github.com/Laisky/ramjet/commit/d5ef023fa594a9abfaf5c366d8e6a80f25814f8e)
- 2015-12-30 (Laisky) + git pages -> [view commit](https://github.com/Laisky/ramjet/commit/7f73bc3e439c02a838ac589636964ce7af94ddc6)
- 2015-12-30 (Laisky) * #2 add document url to README -> [view commit](https://github.com/Laisky/ramjet/commit/59c2ec019f3e197faddfc5fa8b275c2cb7f00d5a)
- 2015-12-30 (Laisky) * #2 mkdocs -> [view commit](https://github.com/Laisky/ramjet/commit/acdcc83ce887ee8ff3fc12c35a57a9494ba9e0a6)
- 2015-12-30 (Laisky) * #2 rename CHANGELOG -> [view commit](https://github.com/Laisky/ramjet/commit/30f5fac8a366711c4db26914d4630a043e3fc1ba)
- 2015-12-29 (Laisky) * #2 try -> [view commit](https://github.com/Laisky/ramjet/commit/351fbde6c11d9aacea287f17b30ab227155823f8)
- 2015-12-29 (Laisky) * #2 init -> [view commit](https://github.com/Laisky/ramjet/commit/29c6fb2dff6ffd1519b956dd8af0b4ce06906b67)
- 2015-12-28 (Laisky) 1.1.1 -> [view commit](https://github.com/Laisky/ramjet/commit/5722b046ca8161beb58c30cf0c4964936e294bae)
- 2015-12-28 (Laisky) * add url to setup.py -> [view commit](https://github.com/Laisky/ramjet/commit/e12f926c82c47de9e6906377c46edad79c895574)
- 2015-12-28 (Laisky) * clean req -> [view commit](https://github.com/Laisky/ramjet/commit/74a0fd222b8b3191805c51bcf52011368cff1749)
- 2015-12-28 (Laisky) * fix setup.py to distituls to pypi -> [view commit](https://github.com/Laisky/ramjet/commit/e5848c06ba32d8c06a945c1d9747497699f0f09f)
- 2015-12-28 (Laisky) 1.1 refactor register method   - put task file in ramjet/tasks/   - expose bind_task interface -> [view commit](https://github.com/Laisky/ramjet/commit/75ba274fa94c4d9c25f9b5dcd4a05621d349edfd)
- 2015-12-28 (Laisky) * fix gitignore -> [view commit](https://github.com/Laisky/ramjet/commit/4907f7e0517ea32da7e3b4d1e872f7f9238a0cb9)    
       
*1.1*
---
    
- 2015-12-28 (Laisky) 1.1 -> [view commit](https://github.com/Laisky/ramjet/commit/a74d529cc4cbcc48e4bbe58087902b6768826273)
- 2015-12-27 (Laisky) * fix typo -> [view commit](https://github.com/Laisky/ramjet/commit/e4e90e3d40894ff69c2659c09d71d40bd3ed90a5)    
